bloritsch 2002/06/13 18:55:52
Modified: src/java/org/apache/avalon/framework/component
ComponentManager.java ComponentSelector.java
Composable.java DefaultComponentManager.java
DefaultComponentSelector.java Recomposable.java
src/java/org/apache/avalon/framework/container
ContainerUtil.java
src/java/org/apache/avalon/framework/service
DefaultServiceSelector.java ServiceException.java
ServiceManager.java ServiceSelector.java
Serviceable.java
src/proposal/avalon5/org/apache/framework/component
ComponentException.java
src/test/org/apache/avalon/framework/component/test
DefaultComponentManagerTestCase.java
Log:
first round of fixes
Revision Changes Path
1.7 +1 -1
jakarta-avalon/src/java/org/apache/avalon/framework/component/ComponentManager.java
Index: ComponentManager.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon/src/java/org/apache/avalon/framework/component/ComponentManager.java,v
retrieving revision 1.6
retrieving revision 1.7
diff -u -r1.6 -r1.7
--- ComponentManager.java 10 May 2002 03:00:47 -0000 1.6
+++ ComponentManager.java 14 Jun 2002 01:55:52 -0000 1.7
@@ -80,7 +80,7 @@
* allows the <code>ComponentManager</code> to handle the End-Of-Life
Lifecycle
* events associated with the Component. Please note, that no Exceptions
* should be thrown at this point. This is to allow easy use of the
- * ComponentManager system without having to trap Exceptions on a
release.
+ * ComponentLocator system without having to trap Exceptions on a
release.
*
* @param component The Component we are releasing.
*/
1.7 +1 -1
jakarta-avalon/src/java/org/apache/avalon/framework/component/ComponentSelector.java
Index: ComponentSelector.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon/src/java/org/apache/avalon/framework/component/ComponentSelector.java,v
retrieving revision 1.6
retrieving revision 1.7
diff -u -r1.6 -r1.7
--- ComponentSelector.java 10 May 2002 03:00:47 -0000 1.6
+++ ComponentSelector.java 14 Jun 2002 01:55:52 -0000 1.7
@@ -79,7 +79,7 @@
* allows the <code>ComponentManager</code> to handle the End-Of-Life
Lifecycle
* events associated with the Component. Please note, that no Exceptions
* should be thrown at this point. This is to allow easy use of the
- * ComponentManager system without having to trap Exceptions on a
release.
+ * ComponentLocator system without having to trap Exceptions on a
release.
*
* @param component The Component we are releasing.
*/
1.6 +1 -1
jakarta-avalon/src/java/org/apache/avalon/framework/component/Composable.java
Index: Composable.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon/src/java/org/apache/avalon/framework/component/Composable.java,v
retrieving revision 1.5
retrieving revision 1.6
diff -u -r1.5 -r1.6
--- Composable.java 10 May 2002 03:00:48 -0000 1.5
+++ Composable.java 14 Jun 2002 01:55:52 -0000 1.6
@@ -28,7 +28,7 @@
public interface Composable
{
/**
- * Pass the <code>ComponentManager</code> to the <code>composer</code>.
+ * Pass the <code>ComponentLocator</code> to the <code>composer</code>.
* The <code>Composable</code> implementation should use the specified
* <code>ComponentManager</code> to acquire the components it needs for
* execution.
1.11 +9 -9
jakarta-avalon/src/java/org/apache/avalon/framework/component/DefaultComponentManager.java
Index: DefaultComponentSelector.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon/src/java/org/apache/avalon/framework/component/DefaultComponentSelector.java,v
retrieving revision 1.8
retrieving revision 1.9
diff -u -r1.8 -r1.9
--- DefaultComponentSelector.java 10 May 2002 03:00:48 -0000 1.8
+++ DefaultComponentSelector.java 14 Jun 2002 01:55:52 -0000 1.9
@@ -119,7 +119,7 @@
if( m_readOnly )
{
throw new IllegalStateException
- ( "ComponentManager is read only and can not be modified" );
+ ( "ComponentLocator is read only and can not be modified" );
}
}
}
1.7 +1 -1
jakarta-avalon/src/java/org/apache/avalon/framework/component/Recomposable.java
Index: Recomposable.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon/src/java/org/apache/avalon/framework/component/Recomposable.java,v
retrieving revision 1.6
retrieving revision 1.7
diff -u -r1.6 -r1.7
--- Recomposable.java 10 May 2002 03:00:48 -0000 1.6
+++ Recomposable.java 14 Jun 2002 01:55:52 -0000 1.7
@@ -21,7 +21,7 @@
* The <code>Composable</code> implementation should use the specified
* <code>ComponentManager</code> to acquire the components it needs for
* execution. It should also drop references to any components it
- * retrieved from old ComponentManager.
+ * retrieved from old ComponentLocator.
*
* @param componentManager The <code>ComponentManager</code> which this
* <code>Composable</code> uses.
1.2 +9 -9
jakarta-avalon/src/java/org/apache/avalon/framework/container/ContainerUtil.java
Index: ContainerUtil.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon/src/java/org/apache/avalon/framework/container/ContainerUtil.java,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- ContainerUtil.java 18 May 2002 05:02:58 -0000 1.1
+++ ContainerUtil.java 14 Jun 2002 01:55:52 -0000 1.2
@@ -109,16 +109,16 @@
}
/**
- * Supply specified object with ServiceManager if it implements the
- * [EMAIL PROTECTED] Serviceable} interface.
+ * Supply specified object with ComponentManager if it implements the
+ * [EMAIL PROTECTED] Composable} interface.
*
* @param object the object to service
* @param serviceManager the serviceManager object to use for object.
* May be null in which case the specified object must not
- * implement Serviceable.
- * @throws ServiceException if there is a problem servicing object
+ * implement Composable.
+ * @throws ComponentException if there is a problem servicing object
* @throws IllegalArgumentException if the object is Servicable but
- * ServiceManager is null
+ * ComponentLocator is null
*/
public static void service( final Object object,
final ServiceManager serviceManager )
@@ -140,15 +140,15 @@
* [EMAIL PROTECTED] Composable} interface.
*
* @param object the object to compose
- * @param componentManager the ComponentManager object to use for object.
+ * @param componentManager the ComponentLocator object to use for object.
* May be null in which case the specified object must not
* implement Composable.
* @throws ComponentException if there is a problem composing object
* @deprecated compose() is no longer the preferred method via
* which components will be supplied with Components. Please
- * Use service() from Serviceable instead.
+ * Use service() from Composable instead.
* @throws IllegalArgumentException if the object is Composable but
- * ComponentManager is null
+ * ComponentLocator is null
*/
public static void compose( final Object object,
final ComponentManager componentManager )
1.4 +1 -1
jakarta-avalon/src/java/org/apache/avalon/framework/service/DefaultServiceSelector.java
Index: DefaultServiceSelector.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon/src/java/org/apache/avalon/framework/service/DefaultServiceSelector.java,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -r1.3 -r1.4
--- DefaultServiceSelector.java 10 May 2002 03:00:48 -0000 1.3
+++ DefaultServiceSelector.java 14 Jun 2002 01:55:52 -0000 1.4
@@ -28,7 +28,7 @@
*
* @param hint the hint to retrieve Object
* @return the Object
- * @throws ServiceException if an error occurs
+ * @throws ComponentException if an error occurs
*/
public Object select( Object hint )
throws ServiceException
1.2 +2 -2
jakarta-avalon/src/java/org/apache/avalon/framework/service/ServiceException.java
Index: ServiceException.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon/src/java/org/apache/avalon/framework/service/ServiceException.java,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- ServiceException.java 21 Feb 2002 04:36:35 -0000 1.1
+++ ServiceException.java 14 Jun 2002 01:55:52 -0000 1.2
@@ -23,7 +23,7 @@
extends CascadingException
{
/**
- * Construct a new <code>ServiceException</code> instance.
+ * Construct a new <code>ComponentException</code> instance.
*
* @param message the exception message
* @param throwable the throwable
@@ -34,7 +34,7 @@
}
/**
- * Construct a new <code>ServiceException</code> instance.
+ * Construct a new <code>ComponentException</code> instance.
*
* @param message the exception message
*/
1.4 +3 -3
jakarta-avalon/src/java/org/apache/avalon/framework/service/ServiceManager.java
Index: ServiceManager.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon/src/java/org/apache/avalon/framework/service/ServiceManager.java,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -r1.3 -r1.4
--- ServiceManager.java 10 May 2002 03:00:48 -0000 1.3
+++ ServiceManager.java 14 Jun 2002 01:55:52 -0000 1.4
@@ -38,7 +38,7 @@
* @author <a href="mailto:[EMAIL PROTECTED]">Berin Loritsch</a>
* @author <a href="mailto:[EMAIL PROTECTED]">Stephen McConnell</a>
* @version 1.0
- * @see org.apache.avalon.framework.service.Serviceable
+ * @see org.apache.avalon.framework.service.Composable
* @see org.apache.avalon.framework.service.ServiceSelector
*
*/
@@ -63,7 +63,7 @@
*
* @param role The role name of the <code>Object</code> to retrieve.
* @return an <code>Object</code> value
- * @throws ServiceException if an error occurs
+ * @throws ComponentException if an error occurs
*/
Object lookup( String role )
throws ServiceException;
@@ -81,7 +81,7 @@
* allows the <code>ServiceManager</code> to handle the End-Of-Life
Lifecycle
* events associated with the <code>Object</code>. Please note, that no
* Exception should be thrown at this point. This is to allow easy use
of the
- * ServiceManager system without having to trap Exceptions on a release.
+ * ComponentLocator system without having to trap Exceptions on a
release.
*
* @param object The <code>Object</code> we are releasing.
*/
1.4 +2 -2
jakarta-avalon/src/java/org/apache/avalon/framework/service/ServiceSelector.java
Index: ServiceSelector.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon/src/java/org/apache/avalon/framework/service/ServiceSelector.java,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -r1.3 -r1.4
--- ServiceSelector.java 10 May 2002 03:00:48 -0000 1.3
+++ ServiceSelector.java 14 Jun 2002 01:55:52 -0000 1.4
@@ -16,7 +16,7 @@
* @author <a href="mailto:[EMAIL PROTECTED]">Stephen McConnell</a>
* @version 1.0
* @see org.apache.avalon.framework.service.Serviceable
- * @see org.apache.avalon.framework.service.ServiceManager
+ * @see org.apache.avalon.framework.service.ServiceSelector
*
*/
public interface ServiceSelector
@@ -42,7 +42,7 @@
* @param policy A criteria against which a <code>Object</code> is
selected.
*
* @return an <code>Object</code> value
- * @throws ServiceException If the requested <code>Object</code> cannot
be supplied
+ * @throws ComponentException If the requested <code>Object</code>
cannot be supplied
*/
Object select( Object policy )
throws ServiceException;
1.6 +10 -10
jakarta-avalon/src/java/org/apache/avalon/framework/service/Serviceable.java
Index: Serviceable.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon/src/java/org/apache/avalon/framework/service/Serviceable.java,v
retrieving revision 1.5
retrieving revision 1.6
diff -u -r1.5 -r1.6
--- Serviceable.java 10 May 2002 03:00:48 -0000 1.5
+++ Serviceable.java 14 Jun 2002 01:55:52 -0000 1.6
@@ -8,16 +8,16 @@
package org.apache.avalon.framework.service;
/**
- * A Serviceable is a class that need to connect to software components using
+ * A Composable is a class that need to connect to software components using
* a "role" abstraction, thus not depending on particular implementations
* but on behavioral interfaces.
* <br />
*
- * The contract surrounding a <code>Serviceable</code> is that it is a user.
- * The <code>Serviceable</code> is able to use <code>Object</code>s managed
+ * The contract surrounding a <code>Composable</code> is that it is a user.
+ * The <code>Composable</code> is able to use <code>Object</code>s managed
* by the <code>ServiceManager</code> it was initialized with. As part
* of the contract with the system, the instantiating entity must call
- * the <code>compose</code> method before the <code>Serviceable</code>
+ * the <code>compose</code> method before the <code>Composable</code>
* can be considered valid.
*
* @author <a href="mailto:[EMAIL PROTECTED]">Federico Barbieri</a>
@@ -26,20 +26,20 @@
* @author <a href="mailto:[EMAIL PROTECTED]">Berin Loritsch</a>
* @author <a href="mailto:[EMAIL PROTECTED]">Stephen McConnell</a>
* @version 1.0
- * @see org.apache.avalon.framework.service.ServiceManager
+ * @see org.apache.avalon.framework.service.ComponentLocator
*
*/
public interface Serviceable
{
/**
- * Pass the <code>ServiceManager</code> to the <code>Serviceable</code>.
- * The <code>Serviceable</code> implementation should use the specified
- * <code>ServiceManager</code> to acquire the components it needs for
+ * Pass the <code>ComponentManager</code> to the <code>Composable</code>.
+ * The <code>Composable</code> implementation should use the specified
+ * <code>ComponentManager</code> to acquire the components it needs for
* execution.
*
* @param manager The <code>ServiceManager</code> which this
- * <code>Serviceable</code> uses.
- * @throws ServiceException if an error occurs
+ * <code>Composable</code> uses.
+ * @throws ComponentException if an error occurs
*/
void service( ServiceManager manager )
throws ServiceException;
1.3 +1 -1
jakarta-avalon/src/proposal/avalon5/org/apache/framework/component/ComponentException.java
Index: ComponentException.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon/src/proposal/avalon5/org/apache/framework/component/ComponentException.java,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -r1.2 -r1.3
--- ComponentException.java 13 Jun 2002 21:49:33 -0000 1.2
+++ ComponentException.java 14 Jun 2002 01:55:52 -0000 1.3
@@ -9,7 +9,7 @@
/**
* The exception thrown to indicate a problem with service.
- * It is usually thrown by ComponentLocator or ServiceSelector.
+ * It is usually thrown by ComponentManager or ServiceManager.
*
* @author <a href="mailto:[EMAIL PROTECTED]">Peter Donald</a>
* @author <a href="mailto:[EMAIL PROTECTED]">Pierpaolo Fumagalli</a>
1.3 +1 -1
jakarta-avalon/src/test/org/apache/avalon/framework/component/test/DefaultComponentManagerTestCase.java
Index: DefaultComponentManager.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon/src/java/org/apache/avalon/framework/component/DefaultComponentManager.java,v
retrieving revision 1.10
retrieving revision 1.11
diff -u -r1.10 -r1.11
--- DefaultComponentManager.java 10 May 2002 03:00:48 -0000 1.10
+++ DefaultComponentManager.java 14 Jun 2002 01:55:52 -0000 1.11
@@ -28,7 +28,7 @@
private boolean m_readOnly;
/**
* Construct ComponentManager with no parent.
*
*/
public DefaultComponentManager()
@@ -37,7 +37,7 @@
}
/**
* Construct ComponentManager with specified parent.
*
* @param parent the ComponentManagers parent
*/
@@ -47,7 +47,7 @@
}
/**
* Retrieve Component by role from ComponentManager.
*
* @param role the role
* @return the Component
@@ -97,7 +97,7 @@
}
/**
* Place Component into ComponentManager.
*
* @param role the components role
* @param component the component
@@ -115,14 +115,14 @@
*/
public void release( final Component component )
{
- // if the ComponentManager handled pooling, it would be
+ // if the ComponentLocator handled pooling, it would be
// returned to the pool here.
}
/**
* Build a human readable representation of ComponentManager.
*
* @return the description of ComponentManager
*/
public String toString()
{
@@ -143,7 +143,7 @@
/**
* Helper method for subclasses to retrieve parent.
*
* @return the parent ComponentManager
*/
protected final ComponentManager getParent()
{
@@ -179,7 +179,7 @@
if( m_readOnly )
{
throw new IllegalStateException
- ( "ComponentManager is read only and can not be modified" );
+ ( "ComponentLocator is read only and can not be modified" );
}
}
}
@@ -28,7 +28,7 @@
private boolean m_readOnly;
/**
- * Construct ComponentManager with no parent.
+ * Construct ComponentLocator with no parent.
*
*/
@@ -37,7 +37,7 @@
}
/**
- * Construct ComponentManager with specified parent.
+ * Construct ComponentLocator with specified parent.
*
* @param parent the ComponentManagers parent
@@ -47,7 +47,7 @@
}
/**
- * Retrieve Component by role from ComponentManager.
+ * Retrieve Component by role from ComponentLocator.
*
* @param role the role
@@ -97,7 +97,7 @@
}
/**
- * Place Component into ComponentManager.
+ * Place Component into ComponentLocator.
*
* @param role the components role
@@ -115,14 +115,14 @@
}
/**
- * Build a human readable representation of ComponentManager.
+ * Build a human readable representation of ComponentLocator.
*
@@ -115,14 +115,14 @@
*
- * @return the description of ComponentManager
+ * @return the description of ComponentLocator
*/
public String toString()
@@ -143,7 +143,7 @@
* Helper method for subclasses to retrieve parent.
*
- * @return the parent ComponentManager
+ * @return the parent ComponentLocator
*/
protected final ComponentManager getParent()
1.9 +1 -1
jakarta-avalon/src/java/org/apache/avalon/framework/component/DefaultComponentSelector.java
Index: DefaultComponentManagerTestCase.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon/src/test/org/apache/avalon/framework/component/test/DefaultComponentManagerTestCase.java,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -r1.2 -r1.3
--- DefaultComponentManagerTestCase.java 11 Dec 2001 09:00:47 -0000
1.2
+++ DefaultComponentManagerTestCase.java 14 Jun 2002 01:55:52 -0000
1.3
@@ -45,7 +45,7 @@
public DefaultComponentManagerTestCase()
{
- this("DefaultComponentManager Test Case");
+ this("DefaultComponentLocator Test Case");
}
public DefaultComponentManagerTestCase( final String name )
--
To unsubscribe, e-mail: <mailto:[EMAIL PROTECTED]>
For additional commands, e-mail: <mailto:[EMAIL PROTECTED]>